# Professional Damage's Rifling System
![img](rifling_system.png)

## Overview
As part of the barrel manufacturing process the bore of the pipe/barrel must be rifled to enable the bullet to be
stabalised after it leaves the barrel.

The rifling differs per cartridge. These specifications are taken from SAAMI.

[SAAMI Chamber Drawings](https://saami.org/technical-information/cartridge-chamber-drawings/)

For example, the .22LR cartridge needs a bore diameter of 5.51mm (.217") and rifling groove depths of 5.64mm (0.222").

![img.png](img.png)

A great way to achieve this is with Electro Chemical Machining (ECM).

This document will outline the basic steps to rifle the barrel using ECM.

## Process

![img_7.png](img_7.png)

_Referring to the diagram for below explanation._

To cut the rifling grooves, electrolyte solution is ran through the boring fixture (15) 
using a high pressure pump.

A current is run between the barrel (16) and the rifling mandrill (14) that runs down the centre.

O-rings in the fixtures stop the high pressure electrolyte from leaking. Clamps (13) ensure the fixtures do not blow off
during operation.

### Specific materials:
- 1x rifling mandrill
- 1x rifling fixture
- 1x barrel
- 2x O-rings to match barrel diameter
- 2x 25mm worm drive hose clamps

### Basic materials:

[Material list](Materials_general_ECM.md)

## Warnings

[See warnings](Warnings.md)

## Mandrill Assembly
Refer to [print settings](Printing_instructions.md) for details on printing the mandrills.


![img_9.png](img_9.png)

Materials:
- Strong wire pliers 
- Vice grips 
- Copper max 0.8mm wire or equivalent 
- Acetone or superglue (Acetone for ABS only)

Method:
1. Print and label all parts and carefully remove support brims
2. Use 2mm rod or wire inserted in the mandrill holes to align mandrill parts
3. If using ABS dunk the tip of the mandrill to be glued in ABS and blow off the excess acetone
4. Using a clamp or vice keep the parts aligned and clamped for at least 15 minutes until they cure
5. Continue gluing each part until the full mandrill has been made
6. Leave the completed mandrill to sit for at least a few hours on a flat surface to cure completely
7. Measure out 6 lengths of wire that are sufficient in length for the mandrill
8. Straighten each piece by clamping it in a vice and pulling on the other end
9. Carefully thread each piece of wire through from the base to the tip
10. At the tip solder or twist the wires together
11. Twist the wire tightly at the base to eliminate any slack
12. This action should straighten the mandrill as each wire will pull uniformly
13. Make an ABS slurry by mixing ABS with acetone (or use other method)
14. Apply the thick slurry to the base of the mandrill only to fill up the holes
15. Finally, press the mandrill into the mandrill base and apply superglue/acetone to bond them together
16. Ensure the base of the mandrill is flush with the base of the other part
17. Carefully put it inside a barrel blank (so it is aligned) and leave to cure for several hours to a day


## Preparation

Using brake cleaner, acetone or similar solvent to make spotless the inside of the barrel. This will require forcing
solvent soaked pieces of rag down the barrel several times to remove all impurities.

Anything that can insulate electrical current will affect the cut of the barrel.

## Method

Mark the barrel using a sharp hard object as to locate it against the barrel

![img_8.png](img_8.png)

Mark the rifling mandrill using permanent marker so the mandrill is placed in the same position each time

### If using 6 wire mandrill:
1. Cut until depth is achieved

### If using a 3 wire mandrill:

1. keep cutting until half of the cut is achieved
2. IE: 5.64-5.51 = 0.13; 0.13/2 + 5.51 = 5.575mm
3. Keep track of the minutes taken to cut
4. Rotate the mandrill 180 degrees and cut for the exact same time as the opposite side

Then follow the general instructions:

[General ECM steps](General_steps_ECM.md)


## Notes
During operation a layer of scum will build on the bucket. This is normal and there is nothing you can do to prevent it.

It was thought that adding Citric Acid would help with the scum, but it actually seems to just deteriorate the electrode
and diminish the quality of the cut.

The toxicity of the electrolyte is unknown. So use gloves etc.

